package weaver.interfaces.jcl.poc.action;

import com.engine.common.util.ServiceUtil;
import com.engine.hrm.service.impl.OrganizationServiceImpl;
import weaver.conn.RecordSet;
import weaver.general.BaseBean;
import weaver.general.Util;
import weaver.hrm.User;
import weaver.interfaces.workflow.action.Action;
import weaver.soa.workflow.request.MainTableInfo;
import weaver.soa.workflow.request.Property;
import weaver.soa.workflow.request.RequestInfo;
import weaver.workflow.request.RequestManager;

import java.util.HashMap;
import java.util.Map;

/**
 * 组织调整流程,归档Action
 *
 * @author:dxfeng
 * @createTime: 2024/04/17
 * @version: 1.0
 */
public class AdjustDepartmentNameAction implements Action {
    @Override
    public String execute(RequestInfo requestInfo) {
        try {
            RequestManager requestManager = requestInfo.getRequestManager();
            User user = requestManager.getUser();
            MainTableInfo mainTableInfo = requestInfo.getMainTableInfo();
            Property[] propertyArray = mainTableInfo.getProperty();
            Map<String, String> mainMap = new HashMap<>(16);

            for (Property property : propertyArray) {
                mainMap.put(property.getName(), property.getValue());
            }

            String departmentId = mainMap.get("yzz");
            String newDepartmentName = mainMap.get("gm");
            RecordSet rs = new RecordSet();
            // 更新部门全称、简称
            rs.executeUpdate("update hrmdepartment set departmentmark = ?,departmentname = ? where id = ?", newDepartmentName, newDepartmentName, departmentId);
            Map<String, Object> map = new HashMap<>();
            // 构建原来的部门数据集合
            buildEcDepartmentData(map, departmentId);
            map.put("departmentmark", newDepartmentName);
            map.put("departmentname", newDepartmentName);
            Map<String, Object> resultMap = ServiceUtil.getService(OrganizationServiceImpl.class, user).editDepartment(map, user);
            if ("-1".equals(Util.null2String(resultMap.get("status")))) {
                requestInfo.getRequestManager().setMessagecontent(Util.null2String(resultMap.get("message")));
                return FAILURE_AND_CONTINUE;
            }
            return SUCCESS;
        } catch (Exception e) {
            new BaseBean().writeLog(e);
            requestInfo.getRequestManager().setMessagecontent("操作失败，请联系系统管理处理");
            return FAILURE_AND_CONTINUE;
        }
    }

    /**
     * 构建原部门信息集合
     *
     * @param map
     * @param ecDepartment
     */
    private void buildEcDepartmentData(Map<String, Object> map, String ecDepartment) {
        map.put("id", ecDepartment);
        RecordSet rs = new RecordSet();
        // 先查拓展表
        rs.execute("select * from hrmdepartmentdefined where deptid = '" + ecDepartment + "'");
        int colcount = rs.getColCounts();
        if (rs.next()) {
            for (int i = 1; i <= colcount; i++) {
                map.put(rs.getColumnName(i).toLowerCase(), Util.null2String(rs.getString(i)));
            }
        }
        // 再查主表
        rs.execute("select * from hrmdepartment where id = '" + ecDepartment + "'");
        colcount = rs.getColCounts();
        if (rs.next()) {
            for (int i = 1; i <= colcount; i++) {
                map.put(rs.getColumnName(i).toLowerCase(), Util.null2String(rs.getString(i)));
            }
        }
    }
}
