package weaver.interfaces.jcl.poc.action;

import com.engine.common.util.ServiceUtil;
import com.engine.organization.entity.staff.param.StaffOutParam;
import com.engine.organization.enums.StaffChangeEnum;
import com.engine.organization.exception.OrganizationRunTimeException;
import com.engine.organization.service.impl.StaffOutServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.util.StringUtil;
import weaver.conn.RecordSet;
import weaver.general.BaseBean;
import weaver.hrm.User;
import weaver.interfaces.workflow.action.Action;
import weaver.soa.workflow.request.MainTableInfo;
import weaver.soa.workflow.request.Property;
import weaver.soa.workflow.request.RequestInfo;
import weaver.workflow.request.RequestManager;

import java.util.HashMap;
import java.util.Map;

/**
 * @author:dxfeng
 * @createTime: 2024/04/17
 * @version: 1.0
 */
public class AdjustDepartmentStaffAction implements Action {
    @Override
    public String execute(RequestInfo requestInfo) {
        try {
            RequestManager requestManager = requestInfo.getRequestManager();
            User user = requestManager.getUser();
            MainTableInfo mainTableInfo = requestInfo.getMainTableInfo();
            Property[] propertyArray = mainTableInfo.getProperty();
            Map<String, String> mainMap = new HashMap<>(16);

            for (Property property : propertyArray) {
                mainMap.put(property.getName(), property.getValue());
            }

            String departmentId = mainMap.get("bm");
            String dz = mainMap.get("dz");

            // 查询对应的该部门对应的编制方案
            String planId = "";
            String companyId = "";
            RecordSet rs = new RecordSet();
            rs.executeQuery("select a.plan_id , a.ec_company from jcl_org_staff a inner join jcl_org_staffplan b on a.plan_id = b.id and b.forbidden_tag = 0 and b.delete_type = 0 where a.ec_department = ? and a.job_id is null and a.delete_type = 0", departmentId);
            if (rs.next()) {
                planId = rs.getString("plan_id");
                companyId = rs.getString("ec_company");
            }
            if (StringUtils.isBlank(planId)) {
                requestInfo.getRequestManager().setMessagecontent("未获取到编制信息，请先在编制信息列表维护该部门编制");
                return FAILURE_AND_CONTINUE;
            }
            int dzNum = Integer.parseInt(dz);
            StaffOutServiceImpl staffOutService = ServiceUtil.getService(StaffOutServiceImpl.class, user);
            StaffOutParam staffOutParam = new StaffOutParam();
            staffOutParam.setType(dzNum > 0 ? StaffChangeEnum.ADD : StaffChangeEnum.REDUCE);
            staffOutParam.setPlanId(Integer.parseInt(planId));
            staffOutParam.setCompany(Integer.parseInt(companyId));
            staffOutParam.setDepartment(Integer.parseInt(departmentId));
            staffOutParam.setChangeMode(1);
            staffOutParam.setNum(Math.abs(dzNum));
            Integer integer = staffOutService.changeStaff(staffOutParam);
            return SUCCESS;

        } catch (OrganizationRunTimeException e) {
            requestInfo.getRequestManager().setMessagecontent(e.getMessage());
            return FAILURE_AND_CONTINUE;
        } catch (Exception e) {
            new BaseBean().writeLog(e);
            requestInfo.getRequestManager().setMessagecontent("操作失败，请联系系统管理处理");
            return FAILURE_AND_CONTINUE;
        }
    }
}
